# -*- coding: utf-8 -*-
from ppms.migration import BasePacket, PacketCategory, MinVersionDependency, MaxVersionDependency
from ppms import ppms
from ppms.constants import *
try:
    from ppms.start_tcalc import start_new_planning
except ImportError:
    pass


class UnloadAndReplan(BasePacket):
    """Runs an unload and a replanning over all active projects.

    If this migration packet fails then please check the state of the packet A_CreateConstraints.
    If there are still errors with the constraints those will need to be corrected before
    performing a replanning.

    Please correct the errors that were found by A_CreateConstraints before running this packet again.
    """
    wi_number = 17217
    done_after_success = False
    run_on_startup = True
    category = PacketCategory.CATEGORY_MANDATORY

    def fix(self, packet_runner):
        pr_list = [pr_id[0] for pr_id in ppms.db_select("select DI001001 from DT461 where DI001042 = 1")]
        self.log("Starting recalculation of the following projects: " + str(pr_list))
        start_new_planning(None, pr_list=pr_list, calc_portfolios=True)

        return self.success()